"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var namingService_1 = require("./namingService");
describe("Naming Service", function () {
    it("Creates a short name for an azure region", function () {
        var expected = "ausse";
        var actual = namingService_1.AzureNamingService.createShortAzureRegionName("australiasoutheast");
        expect(actual).toEqual(expected);
    });
    it("Creates a short stage name from a well known name", function () {
        var expected = "prod";
        var actual = namingService_1.AzureNamingService.createShortStageName("production");
        expect(actual).toEqual(expected);
    });
    it("Creates a short stage name from a unknown name", function () {
        var value = "user acceptance";
        var actual = namingService_1.AzureNamingService.createShortStageName(value);
        expect(actual).toEqual(value.substr(0, 3));
    });
    it("Creates a short stage name from multiple values", function () {
        var actual = namingService_1.AzureNamingService.createShortStageName("production dogfood");
        expect(actual).toEqual("proddf");
    });
    it("Creates unique short names for all azure regions", function () {
        var regions = [
            "eastasia",
            "southeastasia",
            "centralus",
            "eastus",
            "eastus2",
            "westus",
            "northcentralus",
            "southcentralus",
            "northeurope",
            "westeurope",
            "japanwest",
            "japaneast",
            "brazilsouth",
            "australiaeast",
            "australiasoutheast",
            "southindia",
            "centralindia",
            "westindia",
            "canadacentral",
            "canadaeast",
            "uksouth",
            "ukwest",
            "westcentralus",
            "westus2",
            "koreacentral",
            "koreasouth",
            "francecentral",
            "francesouth",
            "australiacentral",
            "australiacentral2",
            "uaecentral",
            "uaenorth",
            "southafricanorth",
            "southafricawest"
        ];
        var results = {};
        regions.forEach(function (region) {
            var result = namingService_1.AzureNamingService.createShortAzureRegionName(region);
            results[result] = region;
        });
        expect(Object.keys(results)).toHaveLength(regions.length);
    });
    it("gets a normalized region name from full region name", function () {
        var result = namingService_1.AzureNamingService.getNormalizedRegionName("West US 2");
        expect(result).toEqual("westus2");
    });
    it("Performs noop if region name is already normalized", function () {
        var expected = "westus2";
        var actual = namingService_1.AzureNamingService.getNormalizedRegionName(expected);
        expect(actual).toEqual(expected);
    });
    it("deployment name is generated correctly", function () {
        var config = {
            functions: [],
            plugins: [],
            provider: {
                prefix: "sls",
                name: "azure",
                region: "westus",
                stage: "dev",
            },
            service: "test-api"
        };
        var timestamp = Date.now();
        var deploymentName = namingService_1.AzureNamingService.getDeploymentName(config, "t" + timestamp);
        expect(deploymentName).toEqual("slswusdevtestapi-DEPLOYMENT-t" + timestamp);
        assertValidDeploymentName(config, deploymentName, timestamp);
    });
    it("deployment name with long suffix or service name generated correctly", function () {
        var config = {
            functions: [],
            plugins: [],
            provider: {
                prefix: "sls-long-prefix-name",
                name: "azure",
                region: "westus",
                stage: "multicloud",
            },
            service: "extra-long-service-name"
        };
        var timestamp = Date.now();
        var deploymentName = namingService_1.AzureNamingService.getDeploymentName(config, "t" + timestamp);
        expect(deploymentName).toEqual("slswusmulext-DEPLOYMENT-t" + timestamp);
        assertValidDeploymentName(config, deploymentName, timestamp);
    });
    function assertValidDeploymentName(config, value, timestamp) {
        expect(value.length).toBeLessThanOrEqual(64);
        expect(value).toContain(timestamp);
        expect(value).toContain(namingService_1.AzureNamingService.createShortAzureRegionName(config.provider.region));
        expect(value).toContain(createSafeString(config.provider.prefix));
        expect(value).toContain(createSafeString(config.provider.stage));
        expect(value).toContain(createSafeString(config.service));
    }
    function createSafeString(value) {
        return value.replace(/\W+/g, "").toLowerCase().substr(0, 3);
    }
    ;
});
